(
	global dsRollout

	try ( DestroyDialog dsRollout ) catch()

	local minMaxVersion = 16900
	local allowInstallOnLegacy = false
	local messageBoxTitle = "ExploreX Installer"

	local readMeFile = ((GetDir #temp)+ @"\ExploreX\_ReadMe.txt")
	local sourceScript=((GetDir #temp)+ @"\ExploreX\SF_ExploreX_V1.0.mse")
	local sourceMacro =(GetDir #temp)+ @"\ExploreX\Spacefrog Tools-ExploreX_Macros.mcr"
	
	local targetScript =  ((GetDir #userstartupScripts) + @"\SF_ExploreX_V1.0.mse")
	local targetMacro =  (GetDir #usermacros) + @"\Spacefrog Tools-ExploreX_Macros.mcr"	

						  

	rollout dsRollout "ExploreX V1.0 Installer" width:490
	(
		group "ExploreX Release V1.0 for 3ds Max 2015+"
		(		
			button btInstallOnly "Install" width:140 height:28  across:3
			
			button btUninstall "Uninstall" width:140 height:28
			
			button btOpenReadme "Read Me!"  width:140 height:28
			
			edittext etMessage readonly:true width:478 height:64 align:#center offset:[-4,8]
		)

		on dsRollout open do
		(
			btUninstall.enabled = DoesFileExist targetScript  OR DoesFileExist targetMacro	
			
			btInstallOnly.enabled = NOT btUninstall.enabled
			
			if( btUninstall.enabled ) then
				etMessage.text = "An existing installation has been detected.\nPress \"Uninstall\" first to remove the existing version."
			else
				etMessage.text = "Files getting installed with ExploreX:\n\n" + targetScript + "\n" + targetMacro
			
		)
		
		on btOpenReadme pressed do
		(
			ShellLaunch readMeFile ""
		)
		
		function RemoveMenu=
		(		
			-- Find the  menu item
			local explMenu = menuMan.findMenu "ExploreX"
						
			if( explMenu != undefined ) do 
			(
				menuMan.unRegisterMenu explMenu		
				menuMan.updateMenuBar()	
			)				
		)		
		
		function AddMenu=
		(
			RemoveMenu()
			
			local explMenu = menuMan.CreateMenu "ExploreX"

			mi = menuMan.createActionItem "ExploreX_ActiveToggle" "Spacefrog Tools"
			explMenu.addItem mi -1
			mi = menuMan.createActionItem "ExploreX_EditINI" "Spacefrog Tools"
			explMenu.addItem mi -1
			mi = menuMan.createActionItem "ExploreX_ReReadINI" "Spacefrog Tools"
			explMenu.addItem mi -1

			local explMenuItem = menuMan.createSubMenuItem "ExploreX" explMenu

			local mainMenu = menuMan.getMainMenuBar()
					
			-- Add the sub-menu just at the second to last slot
			mainMenu.addItem explMenuItem ( mainMenu.numItems() + 1 )
			menuMan.updateMenuBar()
		)
		
		function Install uninstall:false=
		(
			local result=false
			try
			(					
				if ((DoesFileExist targetScript)  OR (DoesFileExist targetMacro) ) do
				(
					if( (queryBox "Existing ExploreX installation detected.\nRemove the existing version?" title:"ExploreX installation detected" ) == true ) then
					(
						DeleteFile targetScript 
						DeleteFile targetMacro
						
						RemoveMenu()
						
						format "Successfully deleted the following files:\n[%]\n[%]\n" targetScript targetMacro
						result=true
					)
					else format "ExploreX Installer: Uninstallation canceled...\n"					
				)

				if( Uninstall == false ) then
				(
					if( (copyFile sourceScript targetScript)  AND (copyFile sourceMacro targetMacro) ) then
					(
						---PatchOptions targetScript    -- not implemented right now
						MessageBox "ExploreX installed and activated successfully..." title:messageBoxTitle						
					)
					else
						throw ("Error copying [" + sourceScript + "] to [" + targetScript + "]")

					btUninstall.enabled = DoesFileExist targetScript
					btInstallOnly.enabled= NOT btUninstall.enabled					
					result=true
				)
				else 
				(
					btUninstall.enabled = ( DoesFileExist targetScript ) OR (DoesFileExist targetMacro)
					btInstallOnly.enabled= NOT btUninstall.enabled					
				)
			)
			catch
			(
				format "ExploreX Installer: Installation failed, %\n" (GetCurrentException())
				result=false
			)
			result
		)


		

		on btInstallOnly pressed do
		(
			if( Install() == true ) then
			(
				filein targetScript
				filein targetMacro				
				
				AddMenu()				
				
			)
		)

		on btUninstall pressed do
		(		
			if( Install uninstall:true ) do
			(
				if( isStruct ExploreX AND isProperty ExploreX #deactivate ) do
				(
					ExploreX.deactivate()
					ExploreX = undefined
				)
				Messagebox "ExploreX removed successfully...\nPlease restart 3ds Max!"
			)
		)
	)
	local result=true
	if( (Maxversion())[1] < minMaxVersion ) do
	(
		if( allowInstallOnLegacy == true ) then
			result =queryBox "ExploreX was written for 3ds Max 2015 or newer.\nAn earlier version has been detected, still continue?" title:"Continue installation?" beep:true
		else 
		(
			MessageBox "ExploreX was written for 3ds Max 2015 or newer.\nAn earlier, incompatible version has been detected.\nExiting..." title:"Incompatible 3ds Max Installation" beep:true
			result=false
		)		
	)
	if( result ==true ) do CreateDialog dsRollout --modal:true
	ok
)